@@ -91,6 +91,7 @@ Settings::Settings()
   choices->Append(L"Manual definition");
 
   presets->Append(L"Nokia N810 (cm)");
+  presets->Append(L"Nokia N900 (cm)");
 }
 
 Lum::Object* Settings::GetContent()
@@ -171,6 +172,10 @@ void Settings::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
       factor->Set(DoubleToWString(8.95));
       unit->Set(L"cm");
       break;
+    case 2:
+      factor->Set(DoubleToWString(7.00));
+      unit->Set(L"cm");
+      break;
     default:
       assert(false);
     }
